//[mahjong-utils](../../index.md)/[mahjongutils.yaku](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [DefaultYakuSerializer](-default-yaku-serializer/index.md) | [common]<br>object [DefaultYakuSerializer](-default-yaku-serializer/index.md) : KSerializer&lt;[Yaku](-yaku/index.md)&gt; |
| [Yaku](-yaku/index.md) | [common]<br>class [Yaku](-yaku/index.md) : YakuChecker<br>役种 |
| [Yakus](-yakus/index.md) | [common]<br>open class [Yakus](-yakus/index.md)(val options: [HoraOptions](../mahjongutils.hora/-hora-options/index.md))<br>包含所有役种 |
| [YakuSerializer](-yaku-serializer/index.md) | [common]<br>class [YakuSerializer](-yaku-serializer/index.md)(val yakus: [Yakus](-yakus/index.md)) : KSerializer&lt;[Yaku](-yaku/index.md)&gt; |
